jQuery(function($){
  
  LivelyChatSupport = {
    scrollChatToBottom: function() {
      if ($("#livelychatsupport-chatbox").length)
      {
        $("#livelychatsupport-chatbox .messages").animate({
          scrollTop: $("#livelychatsupport-chatbox .messages")[0].scrollHeight
        }, 0);
      }
    },

    mobileDevice: function() {
      return $(window).width() > 720;
    },

    addMessage: function(content, from_agent) {
      var audio = $("#livelychatsupport-chatbox .bell");
      var template = $(".message_template").clone();
      var now = new Date();
      var hours = now.getHours() % 12;
      if (hours == 0) { hours = 12; }
      
      template.removeClass("message_template");
      
      if (from_agent == true) { 
        template.addClass("from_agent");
        audio[0].play();
      }
      
      template.find(".body").text(content);
      template.find(".date").text(hours + ":" + (now.getMinutes() < 10 ? "0" : "") + now.getMinutes());
      template.hide();
      template.appendTo(".messages");
      template.fadeIn();
      LivelyChatSupport.scrollChatToBottom();
    },
    
    poll: function() {
      if ($("#livelychatsupport-chatbox").hasClass("chatting") && $(".messages").length)
      {
        var url = $(".messages").data("url");
        var timestamp = $(".messages").attr("data-timestamp");
        
        $.post(
            url, {
              "action": "poll",
              "timestamp": timestamp
            }, 
            function(response){
              var data = $.parseJSON(response);
              $(".chat").removeClass("chat_loading");

              if (data.messages.length)
              {
                for(i=0; i<data.messages.length; i++) {
                	var message = data.messages[i];
                  if (message.from_agent == "1") { var from_agent = true; } else { var from_agent = false; }
                  LivelyChatSupport.addMessage(message.body, from_agent);
                }
                
                $(".messages").attr("data-timestamp", data["new_time"]);
              }
            
              setTimeout(function(){
                LivelyChatSupport.poll();
              }, 3500);
            }
        );
      }
    }
  }

  $(document).ready(function(){
    LivelyChatSupport.scrollChatToBottom();
    LivelyChatSupport.poll();
  });

  $(document).on("keypress", "#livelychatsupport-chatbox-body", function(e){
    var code = (e.keyCode ? e.keyCode : e.which);
    if (code == 13)
    {
      $(this).closest("form").submit();
      $("#livelychatsupport-chatbox-body").val("");
      return false;
    }
  });

  $(document).on("submit", "#livelychatsupport-chatbox-new-message", function(e){
    $(".chat").addClass("chat_loading");
    
    $.post($(this).attr("action"), {
      "action": "create_message",
      "convo_token": $("#livelychatsupport-chatbox-token").val(),
      "body": $("#livelychatsupport-chatbox-body").val()
    });
    return false;
  });
  
  $(document).on("click", ".livelychatsupport-close, .livelychatsupport-open", function(){
    $("#livelychatsupport-chatbox").toggleClass("open");
  
    if ($(this).closest("#livelychatsupport-chatbox").length) {
      var href = $(this).data("href");
      var open = !(!$("#livelychatsupport-chatbox.open").length);
      $(this).attr("href", href + open);
      if (LivelyChatSupport.mobileDevice() && $("#livelychatsupport-chatbox-new-message:visible").length) { $("#livelychatsupport-chatbox-new-message").focus(); }
      LivelyChatSupport.scrollChatToBottom();
    }
    else
    {
      return false;
    }
  });

  $(document).on("submit", "#livelychatsupport-register", function(){
    if ($("#livelychatsupport-chatbox-name").val() == "" || $("#livelychatsupport-chatbox-email").val() == "" || $("#livelychatsupport-chatbox-email").val().indexOf("@") == -1)
    {
      $("#livelychatsupport-chatbox .prompter .livelychatsupport-error").show(150);
      return false;
    }
    else
    {
      $("#livelychatsupport-chatbox .prompter .livelychatsupport-error").hide(150);
      $("#livelychatsupport-chatbox .prompter form").hide(150);
    
      if ($("#livelychatsupport-chatbox").hasClass("offline"))
      {
        $("#livelychatsupport-chatbox .prompter .offline-thanks").show(150);
      }
      else
      {
        var url = $(this).attr("action");

        $.post(url, {
          "action": "subscribe",
          "convo_token": $("#livelychatsupport-chatbox-token").val(),
          "Name": $("#livelychatsupport-chatbox-name").val(),
          "Email": $("#livelychatsupport-chatbox-email").val(),
          "Comment": $("#livelychatsupport-offline-body").val()
        });
        
        $("#livelychatsupport-chatbox").addClass("chatting");
        if (LivelyChatSupport.mobileDevice()) { $("#livelychatsupport-chatbox-body").focus(); }
        LivelyChatSupport.scrollChatToBottom();
        setTimeout(LivelyChatSupport.poll(), 3000);
      }
    }
    return false;
  });
  
});